# -*- coding: utf-8 -*-
# Module: default
# Author: Roman V. M.
# Created on: 28.11.2014
# License: GPL v.3 https://www.gnu.org/copyleft/gpl.html

import sys
from urlparse import parse_qsl
import xbmc
import xbmcgui
import xbmcplugin
import time
import xbmcaddon


# Get the plugin url in plugin:// notation.
_url = sys.argv[0]
# Get the plugin handle as an integer number.
_handle = int(sys.argv[1])

# Free sample videos are provided by www.vidsplay.com
# Here we use a fixed set of properties simply for demonstrating purposes
# In a "real life" plugin you will need to get info and links to video files/streams
# from some web-site or online service.
CHAINES = [{'name': 'TF1',
            'thumb': 'data/tf1.png',
            'id': 3
            },
           {'name': 'FRANCE 2',
            'thumb': 'data/france2.png',
            'id': 4
            },
           {'name': 'FRANCE 3',
            'thumb': 'data/france3.png',
            'id': 5
            },
           {'name': 'FRANCE 5',
            'thumb': 'data/france5.png',
            'id': 7
            },
           {'name': 'ARTE',
            'thumb': 'data/arte.png',
            'id': 9
            },
           {'name': 'M6',
            'thumb': 'data/m6.png',
            'id': 8
            },
           {'name': 'D8',
            'thumb': 'data/direct8.png',
            'id': 10
            },
           {'name': 'W9',
            'thumb': 'data/w9.png',
            'id': 11
            },
           {'name': 'TMC',
            'thumb': 'data/tmc.png',
            'id': 12
            },
           {'name': 'NT1',
            'thumb': 'data/nt1.png',
            'id': 13
            },
           {'name': 'NRJ12',
            'thumb': 'data/nrj12.png',
            'id': 14
            },
           {'name': 'LCP',
            'thumb': 'data/lcp.png',
            'id': 15
            },
           {'name': 'France 4',
            'thumb': 'data/france4.png',
            'id': 16
            },
           {'name': 'D17',
            'thumb': 'data/d17.png',
            'id': 19
            },
           {'name': 'HD1',
            'thumb': 'data/dh1.png',
            'id': 22
            },
            {'name': 'L Equipe 21',
            'thumb': 'data/lequipe21.png',
            'id': 23
            },
             {'name': '6ter',
            'thumb': 'data/6ter.png',
            'id': 24
            },
            {'name': 'Numéro 23',
            'thumb': 'data/n23.png',
            'id': 25
            },
            {'name': 'Chérie 25',
            'thumb': 'data/cherie25.png',
            'id': 27
            },
           {'name': 'RMC',
            'thumb': 'data/rmcdecouverte.png',
            'id': 26
            }
          ]


def get_chaines():
    """
    Get the list of video categories.
    Here you can insert some parsing code that retrieves
    the list of video categories (e.g. 'Movies', 'TV-shows', 'Documentaries' etc.)
    from some site or server.

    :return: list
    """
    return CHAINES

def list_chaines():
    """
    Create the list of playable videos in the Kodi interface.

    :param category: str
    """
    # Get the list of videos in the category.
    videos = get_chaines()



    # Create a list for our items.
    listing = []
    addon = xbmcaddon.Addon('plugin.video.knetreplay')
    # Iterate through videos.
    for video in videos:
        # Create a list item with a text label and a thumbnail image.
        list_item = xbmcgui.ListItem(label=video['name'])
        # Set additional info for the list item.
        list_item.setInfo('chaine', {'title': video['name'], 'id': video['id']})
        # Set graphics (thumbnail, fanart, banner, poster, landscape etc.) for the list item.
        # Here we use the same image for all items for simplicity's sake.
        # In a real-life plugin you need to set each image accordingly.

        thumbpath=addon.getAddonInfo('path')+'/'+video['thumb']
        list_item.setArt({'thumb': thumbpath, 'icon': thumbpath})
        # Set 'IsPlayable' property to 'true'.
        # This is mandatory for playable items!
        #list_item.setProperty('IsPlayable', 'true')
        # Create a URL for the plugin recursive callback.
        # Example: plugin://plugin.video.example/?action=play&video=http://www.vidsplay.com/vids/crab.mp4
        url = '{0}?action=replay&chaine={1}'.format(_url, video['id'])
        # Add the list item to a virtual Kodi folder.
        # is_folder = False means that this item won't open any sub-list.
        is_folder = True
        # Add our item to the listing as a 3-element tuple.
        listing.append((url, list_item, is_folder))
    # Add our listing to Kodi.
    # Large lists and/or slower systems benefit from adding all items at once via addDirectoryItems
    # instead of adding one by ove via addDirectoryItem.
    xbmcplugin.addDirectoryItems(_handle, listing, len(listing))
    # Add a sort method for the virtual folder items (alphabetically, ignore articles)
    #xbmcplugin.addSortMethod(_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
    # Finish creating a virtual folder.
    xbmcplugin.endOfDirectory(_handle)

def list_categories():
    """
    Create the list of video categories in the Kodi interface.
    """
    # Get video categories
    categories = get_categories()
    # Create a list for our items.
    listing = []
    # Iterate through categories
    for category in categories:
        # Create a list item with a text label and a thumbnail image.
        list_item = xbmcgui.ListItem(label=category, thumbnailImage=VIDEOS[category][0]['thumb'])
        # Set graphics (thumbnail, fanart, banner, poster, landscape etc.) for the list item.
        # Here we use the same image for all items for simplicity's sake.
        # In a real-life plugin you need to set each image accordingly.
        list_item.setArt({'thumb': VIDEOS[category][0]['thumb'],
                          'icon': VIDEOS[category][0]['thumb'],
                          'fanart': VIDEOS[category][0]['thumb']})
        # Set additional info for the list item.
        # Here we use a category name for both properties for for simplicity's sake.
        # setInfo allows to set various information for an item.
        # For available properties see the following link:
        # http://mirrors.xbmc.org/docs/python-docs/15.x-isengard/xbmcgui.html#ListItem-setInfo
        list_item.setInfo('video', {'title': category, 'genre': category})
        # Create a URL for the plugin recursive callback.
        # Example: plugin://plugin.video.example/?action=listing&category=Animals
        url = '{0}?action=listing&category={1}'.format(_url, category)
        # is_folder = True means that this item opens a sub-list of lower level items.
        is_folder = True
        # Add our item to the listing as a 3-element tuple.
        listing.append((url, list_item, is_folder))
    # Add our listing to Kodi.
    # Large lists and/or slower systems benefit from adding all items at once via addDirectoryItems
    # instead of adding one by ove via addDirectoryItem.
    xbmcplugin.addDirectoryItems(_handle, listing, len(listing))
    # Add a sort method for the virtual folder items (alphabetically, ignore articles)
    xbmcplugin.addSortMethod(_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
    # Finish creating a virtual folder.
    xbmcplugin.endOfDirectory(_handle)


def list_videos(category):
    """
    Create the list of playable videos in the Kodi interface.

    :param category: str
    """
    # Get the list of videos in the category.
    videos = get_videos(category)
    # Create a list for our items.
    listing = []
    # Iterate through videos.
    for video in videos:
        # Create a list item with a text label and a thumbnail image.
        list_item = xbmcgui.ListItem(label=video['name'])
        # Set additional info for the list item.
        list_item.setInfo('video', {'title': video['name'], 'genre': video['genre']})
        # Set graphics (thumbnail, fanart, banner, poster, landscape etc.) for the list item.
        # Here we use the same image for all items for simplicity's sake.
        # In a real-life plugin you need to set each image accordingly.
        thumbpath='plugin://plugin.video.knetreplay/'+video['thumb']
        list_item.setArt({'thumb': thumbpath, 'icon': thumbpath, 'fanart': thumbpath})
        # Set 'IsPlayable' property to 'true'.
        # This is mandatory for playable items!
        list_item.setProperty('IsPlayable', 'true')
        # Create a URL for the plugin recursive callback.
        # Example: plugin://plugin.video.example/?action=play&video=http://www.vidsplay.com/vids/crab.mp4
        url = '{0}?action=play&video={1}'.format(_url, video['video'].replace("&", "!!!"))
        # Add the list item to a virtual Kodi folder.
        # is_folder = False means that this item won't open any sub-list.
        is_folder = False
        # Add our item to the listing as a 3-element tuple.
        listing.append((url, list_item, is_folder))
    # Add our listing to Kodi.
    # Large lists and/or slower systems benefit from adding all items at once via addDirectoryItems
    # instead of adding one by ove via addDirectoryItem.
    xbmcplugin.addDirectoryItems(_handle, listing, len(listing))
    # Add a sort method for the virtual folder items (alphabetically, ignore articles)
    xbmcplugin.addSortMethod(_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
    # Finish creating a virtual folder.
    xbmcplugin.endOfDirectory(_handle)


# def playVideoPlayList(url):
#     playList = xbmc.PlayList(xbmc.PLAYLIST_VIDEO)
#     playList.clear()
#     ... read m3u ...
#     for line in m3u_data.splitlines():
#         if line[:1] != "#":
#            ... get part url ...
#             litem = xbmcgui.ListItem(...,path=part)
#             playList.add(part,litem)
#
#     xbmcPlayer = xbmc.Player()
#     xbmcPlayer.play(playList)

def play_video(path):
    """
    Play a video by the provided path.

    :param path: str
    """

    path=path.replace("!!!","&")
    #dialog = xbmcgui.Dialog()
    #dialog.notification('Debug', path, xbmcgui.NOTIFICATION_INFO, 5000)


    # Create a playable item with a path to play.
    #play_item = xbmcgui.ListItem(path=path)
    # Pass the item to the Kodi player.

    #xbmcplugin.setResolvedUrl(_handle, True, listitem=play_item)
    #xbmcplugin.setResolvedUrl(handle=handle, succeeded=True, listitem=xbmcgui.ListItem())
    #playVideoPlayList(url)
    #link='http://ktv.zone/m3u.m3u8?channel=3&timestamp=1455372000&duration=1080'
    xbmc.Player().play(item=path)



def router(paramstring):
    """
    Router function that calls other functions
    depending on the provided paramstring

    :param paramstring:
    """
    # Parse a URL-encoded paramstring to the dictionary of
    # {<parameter>: <value>} elements
    params = dict(parse_qsl(paramstring))
    # Check the parameters passed to the plugin
    if params:
        if params['action'] == 'listing':
            # Display the list of videos in a provided category.
            list_videos(params['category'])
        elif params['action'] == 'play':
            # Play a video from a provided URL.
            play_video(params['video'])
        elif params['action'] == 'replay':
            # Play a video from a provided URL.
            #play_video(params['video'])
            #dialog = xbmcgui.Dialog()
            #dialog.notification('chaine', params['chaine'], xbmcgui.NOTIFICATION_INFO, 1000)
            #chainecourante=params['chaine']
            #dialog.notification('chaine', chainecourante, xbmcgui.NOTIFICATION_INFO, 1000)

            mydisplay = MyClass()
            #mydisplay.doModal()
            mydisplay.askReplay(params['chaine'])
            del mydisplay

    else:
        # If the plugin is called from Kodi UI without any parameters,
        # display the list of video categories
        #list_categories()
        list_chaines()

#get actioncodes from https://github.com/xbmc/xbmc/blob/master/xbmc/guilib/Key.h
ACTION_PREVIOUS_MENU = 10
ACTION_SELECT_ITEM = 7

class MyClass(xbmcgui.Window):
  def __init__(self):


    self.strActionInfo = xbmcgui.ControlLabel(180, 60, 200, 200, '', 'font14', '0xFFBBBBFF')
    #self.addControl(self.strActionInfo)
    #self.strActionInfo.setLabel('Back pour quitter le replay ')

  def onAction(self, action):
    if action == ACTION_PREVIOUS_MENU:
      self.close()

  def askReplay(self,machaine):
    dialog = xbmcgui.Dialog()

    madate=self.DATE()
    if madate == '':
        return

    #self.SELECT()
    monheure=self.TIME()
    if monheure == '':
        return

    #dialog.notification('Debug 2', monheure, xbmcgui.NOTIFICATION_INFO, 1000)

    duree=self.NUMERIC()
    if duree == '':
        return

    #dialog.notification('Debug 3', duree, xbmcgui.NOTIFICATION_INFO, 1000)

    # calcul de l'url de la video

    timestmp = str(int(time.mktime(time.strptime(madate.replace(' ','0')+" "+monheure, "%d/%m/%Y %H:%M"))))
    #dialog.notification('Timestamp', timestmp, xbmcgui.NOTIFICATION_INFO, 1000)

    dureemn=str(int(duree)*60*6)
    #dialog.notification('duree', dureemn, xbmcgui.NOTIFICATION_INFO, 1000)

    # je e trouve rien de mieux qu'une globale pour fixer la chaine courante
    #dialog.notification('Chaine', machaine, xbmcgui.NOTIFICATION_INFO, 1000)

    if dialog.yesno("Démarer le Replay", 'Oui ou Fermer','', "",'Oui','Fermer'):

      self.close()
    else:
      play_video('http://ktv.zone/m3u.m3u8?timestamp='+timestmp+'&duration='+dureemn+'&channel='+machaine+'&')
      self.close()

  def DATE(self):
    dialog = xbmcgui.Dialog()
    d = dialog.numeric(1, 'Date')
    return d

  def NUMERIC(self):
    dialog = xbmcgui.Dialog()
    d = dialog.input('Durée en heure (3 par défaut)', '3', type=xbmcgui.INPUT_NUMERIC)
    return d

  def TIME(self):
    dialog = xbmcgui.Dialog()
    d = dialog.input('Heure', type=xbmcgui.INPUT_TIME)
    return d

if __name__ == '__main__':
    # Call the router function and pass the plugin call parameters to it.
    # We use string slicing to trim the leading '?' from the plugin call paramstring
    router(sys.argv[2][1:])


